# API-Testing-and-Development-with-Postman-Second-Edition

This is the code repository for the [API-Testing-and-Development-with-Postman-Second-Edition](https://www.packtpub.com/product/api-testing-and-development-with-postman-second-edition/9781804617908), published by Packt.
More details are below, pick up your copy today!

**API creation, testing, debugging, and management made easy**

The author of this book is - [Dave Westerveld](https://www.linkedin.com/in/dave-westerveld-25339a42/)

## About the book
Postman is an invaluable tool for exploration and testing of web APIs and helping testers and developers figure out how an API works. With Postman, you can create effective test automation for any APIs, and this guide will help you unleash its full potential.
API Testing and Development with Postman is an invaluable resource for anyone who wants to create a good quality API, but isn't sure how to go about it. This guide will help you unleash the full potential of Postman’s test automation capabilities.
A combination of theory coupled with real-world examples will help you learn how to use Postman to create well-designed, documented, and tested APIs. After you’ve familiarized yourself with the theory, you’ll move on to hands-on projects that will teach you how to add test automation to an existing API. You’ll also learn some of the new and powerful features that Postman has that can help you avoid introducing bugs.
This second, fully updated edition features new chapters on workflow testing, creating and using mock servers, API security testing, and performance testing. The new and expanded information in this edition will help you future-proof your APIs.
By the end of this book, you'll be able to use Postman to set up and run API tests for any API that you are working with.


 
## Key Takeaways
- Find out what is involved in effective API testing
- Leverage Postman to improve the quality of you API
- Use data-driven testing in Postman to create scalable API tests
- How to create and use a Mock Server in Postman
- Verify and improve the quality of an API using contract testing
- Understand the basic principles of security testing
- Get to grips with functional and non-functional testing of an API
- Discover how to use industry standards such as OpenAPI and mocking
 

## What's New
This Second Edition of _API Testing and Development with Postman_ is fully-updated throughout, including modernized coverage on authorization options and API monitoring with Postman. The book also includes four brand-new chapters: Workflow Testing, Creating and using a Mock Server in Postman, API Security Testing, and Performance Testing an API.



## Outline and Chapter Summary
In a world of fast food, fast fashion, and fast-to-market strategies, does quality even matter? The pressures of the world we live in seem to push us towards taking shortcuts, even when it comes to producing high-quality software. I am doing my part to push back against that world. I think quality matters. We have enough easily broken junk in our lives. It’s time for more quality.
This book is one small stake that I’ve put in the ground in an attempt to help the world see more high-quality software. I hope that whether you are a professional tester, or a developer looking to learn more about testing, you will be able to join me in my attempt to improve the world through quality software applications.
APIs are becoming the backbone of the internet. They help companies to communicate with each other externally and also provide the communication infrastructure for many internal pieces of modern software systems. A marriage is held together by good communication, and so it is with the internet too. Good communication between different services is important to well functioning applications. For that reason, API testing matters for producing good-quality software.
On the surface, this book is primarily about the API testing tool Postman, but I have also tried to weave in examples and teachings that will help you to to use that tool in a way that will have a real impact on quality. If you work through this book, you will gain an in-depth grasp of how Postman works, and you will also have a solid foundation in how to think about API testing in general. I want you to have more than just the ability to manipulate Postman to do what you want it to. I also want you to be able to know when and how to use it so that you can be an effective part of creating high-quality APIs. 

1. API Terminology and Types
2. [API Documentation and Design](https://github.com/PacktPublishing/API-Testing-and-Development-with-Postman-Second-Edition/tree/main/Chapter02)
3. [OpenAPI and API Specifications](https://github.com/PacktPublishing/API-Testing-and-Development-with-Postman-Second-Edition/tree/main/Chapter03)
4. [Considerations for Good API Test Automation](https://github.com/PacktPublishing/API-Testing-and-Development-with-Postman-Second-Edition/tree/main/Chapter04)
5. Understanding Authorization Options
6. [Creating Test Validation Scripts](https://github.com/PacktPublishing/API-Testing-and-Development-with-Postman-Second-Edition/tree/main/Chapter06)
7. [Data-Driven Testing](https://github.com/PacktPublishing/API-Testing-and-Development-with-Postman-Second-Edition/tree/main/Chapter07)
8. Workflow Testing
9. [Running API Tests in CI with Newman](https://github.com/PacktPublishing/API-Testing-and-Development-with-Postman-Second-Edition/tree/main/Chapter09)
10. Monitoring APIs with Postman
11. Testing an Existing API
12. Creating and Using Mock Servers in Postman
13. [Using Contract Testing to Verify an API](https://github.com/PacktPublishing/API-Testing-and-Development-with-Postman-Second-Edition/tree/main/Chapter13)
14. [API Security Testing](https://github.com/PacktPublishing/API-Testing-and-Development-with-Postman-Second-Edition/tree/main/Chapter14)
15. Performance Testing an API





### Chapter 01, API Terminology and Types
Chapter 1, API Terminology and Types, gets you started with some of the basic API terminology and introduces you to the different types of APIs.


### Chapter 02, API Documentation and Design
Chapter 2, API Documentation and Design, covers the design principles that apply to creating and testing APIs, and both how and why to create useful documentation.

### Chapter 03, OpenAPI and API Specifications
Chapter 3, Open API and API Specifications, explains what API specifications are and how to get started with using them in Postman.

### Chapter 04, Considerations for Good API Test Automation
Chapter 4, Considerations for Good API Test Automation, teaches you how to create and execute valuable and long-lasting API tests in Postman.

### Chapter 05, Understanding Authorization Options
Chapter 5, Understanding Authorization Options, walks through how to use many of the API authorization methods available in Postman.

### Chapter 06, Creating Test Validation Scripts
Chapter 6, Creating Test Validation Scripts, explains how to create and use test scripts in Postman.

### Chapter 07, Data-Driven Testing
Chapter 7, Data-Driven Testing, discusses what data-driven testing is and how to use it to create scalable tests in Postman.

### Chapter 08, Workflow Testing
Chapter 8, Workflow Testing, explains what workflow tests are and how to create flows in Postman.

### Chapter 09, Running API Tests in CI with Newman
Chapter 9, Running API Tests in CI with Newman, shows how to run Postman API tests at the command line with the Newman runner.

### Chapter 10, Monitoring APIs with Postman
Chapter 10, Monitoring APIs with Postman, explains how to monitor product usage of APIs with Postman monitoring.

### Chapter 11, Testing an Existing API
Chapter 11, Testing an Existing API, works through a hands-on example that shows what kind of tests to create when testing an existing API.

### Chapter 12, Creating and Using Mock Servers in Postman
Chapter 12, Creating and Using Mock Servers in Postman, explains what mock servers are and how to set up and use them in Postman.

### Chapter 13, Using Contract Testing to Verify an API
Chapter 13, Using Contract Testing to Verify an API, discusses what contract testing is and shows how to create and use contract testing in Postman.

### Chapter 14, API Security Testing
Chapter 14, API Security Testing, gives a brief introduction to security testing and gives an example of setting up fuzz testing in Postman.

### Chapter 15, Performance Testing an API
Chapter 15, Performance Testing an API, explains the different types of performance testing and walks through some of the features in Postman that can be used to assess API performance.






## Know more on the Discord server <img alt="Coding" height="25" width="32"  src="https://cliply.co/wp-content/uploads/2021/08/372108630_DISCORD_LOGO_400.gif">
You can get more engaged on the discord server for more latest updates and discussions in the community at [Discord](https://discord.com/invite/nEN6EBYPq9)


## Download a free PDF <img alt="Coding" height="25" width="40" src="https://emergency.com.au/wp-content/uploads/2021/03/free.gif">

_If you have already purchased a print or Kindle version of this book, you can get a DRM-free PDF version at no cost. Simply click on the link to claim your free PDF._
[Free-Ebook](https://packt.link/free-ebook/9781804617908) <img alt="Coding" height="15" width="35"  src="https://media.tenor.com/ex_HDD_k5P8AAAAi/habbo-habbohotel.gif">


We also provide a PDF file that has color images of the screenshots/diagrams used in this book at [GraphicBundle](https://packt.link/gbp/9781804617908) <img alt="Coding" height="15" width="35"  src="https://media.tenor.com/ex_HDD_k5P8AAAAi/habbo-habbohotel.gif">


## Get to know the Author
_Dave Westerveld_ is a developer with many years of testing experience. He has been involved in the testing of numerous projects and he excels at solving automation problems in team environments. He has worked with well-established products and early-stage initiatives, and he is passionate about using automation to improve product quality and to help teams work more efficiently in developing high-value software. Dave has also worked as a developer integrating third-party APIs into applications. Having worked on both the testing and development sides of the SDLC, he has an intimate knowledge of what it takes to create quality code.




## Other Related Books
- [Enterprise API Management](https://www.packtpub.com/product/enterprise-api-management/9781787284432)
- [Building an API Product](https://www.packtpub.com/product/building-an-api-product/9781837630448)













